import { useEffect, useRef, useMemo } from "react";
import { Button, message, Tooltip } from "antd";
import { Graph } from "@antv/x6";
import { handleParseAIData } from "@/utils";
import { getFlowNodeMetaByAi } from "@/utils/flow";
import { getDefaultDataByTheme } from "@/config/data";
import { PlusOutlined } from "@ant-design/icons";

export default function RenderGraph(props: {
  language: string;
  json: string;
  type?: "flow" | "mindmap";
  onInsertFlow?: (data: any) => void;
  showInsert?: boolean;
}) {
  const { language, json, onInsertFlow, showInsert = true, type = "flow" } = props;
  const containerRef = useRef<HTMLDivElement>(null);
  const graphRef = useRef<Graph>();
  const [messageApi, contextHolder] = message.useMessage();
  const parseData = useRef();

  useEffect(() => {
    graphRef.current = new Graph({
      container: containerRef.current!,
      width: containerRef.current!.clientWidth,
      height: containerRef.current!.clientHeight,
      autoResize: true,
      panning: true,
      mousewheel: { enabled: true },
      interacting: {
        edgeLabelMovable: false,
        edgeMovable: false,
        nodeMovable: false,
        arrowheadMovable: false,
      },
      background: {
        color: "#f5f5f5",
      },
    });
  }, []);

  useEffect(() => {
    handleParseAIData({
      content: json,
      message: {
        key: "ai-creator",
        instance: messageApi,
      },
      onSuccess: (data) => {
        parseData.current = data;
        // graphRef.current?.fromJSON(data);
        const defaultDataByTheme = getDefaultDataByTheme("1");

        const list = (Array.isArray(data) ? data : [data]).map((item) =>
          getFlowNodeMetaByAi(item, defaultDataByTheme)
        );

        list.forEach((cell) => {
          if (cell.shape !== "edge") {
            graphRef.current?.addNode(cell);
          }
          if (cell.shape === "edge") {
            graphRef.current?.addEdge(cell);
          }
        });
        graphRef.current?.zoomToFit({
          padding: 20,
        });
      },
      onError: (err) => {
        messageApi.error(err.message);
      },
    });
  }, [language, json]);

  return (
    <div className="w-full">
      {contextHolder}
      <div className="text-14px">以为您生成以下内容:</div>
      <div className="w-full h-300px max-h-300px rounded-4px" ref={containerRef}/>
      <div className="flex mt-8px">
        {showInsert && type === "flow" && (
          <Tooltip title="添加到当前画布">
            <Button
              variant="text"
              size="small"
              color="primary"
              icon={<PlusOutlined />}
              onClick={() => onInsertFlow?.(parseData.current)}
            >
              加入画布
            </Button>
          </Tooltip>
        )}
      </div>
    </div>
  );
}
